uploader

package
v0.0.0-...-c12fb3d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 23, 2025 License: GPL-3.0 Imports: 19 Imported by: 0

Documentation

Overview

Package uploader provides the main implementation of the upload service.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service contains the definition to run the application as a service.

func NewService

func NewService(development bool, version string) *Service

NewService creates a new Service instance.

func (*Service) Start

func (s *Service) Start(svc service.Service) error

Start starts running the service. It will return as soon as possible.

func (*Service) Stop

func (s *Service) Stop(svc service.Service) error

Stop stops the currently running service. It will return as soon as possible.

type Uploader

type Uploader struct {
	Configuration *config.Configuration
	Location      *time.Location
	History       *history.History
	// contains filtered or unexported fields
}

func (*Uploader) Upload

func (u *Uploader) Upload(ctx context.Context)

Upload uses a configuration to run a query on the target database, convert the results to JSON, and upload them to the door2doc integration service.

func (*Uploader) UploadJSON

func (u *Uploader) UploadJSON(ctx context.Context, json *bytes.Buffer, path string, importMode bool) error

Directories

Path Synopsis
Package config manages the configuration options for the uploader.
Package config manages the configuration options for the uploader.
Package db provides generic database access to retrieve the various queries.
Package db provides generic database access to retrieve the various queries.
Package dlog provides a door2doc logger that can be integrated with service logging.
Package dlog provides a door2doc logger that can be integrated with service logging.
Package rest provides the client side implementation of the upload service REST API.
Package rest provides the client side implementation of the upload service REST API.
Package web provides the web-based configuration interface for the service.
Package web provides the web-based configuration interface for the service.

Jump to