Documentation
¶
Overview ¶
Package uploader provides the main implementation of the upload service.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service contains the definition to run the application as a service.
func NewService ¶
NewService creates a new Service instance.
type Uploader ¶
type Uploader struct {
Configuration *config.Configuration
Location *time.Location
History *history.History
// contains filtered or unexported fields
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package config manages the configuration options for the uploader.
|
Package config manages the configuration options for the uploader. |
|
Package db provides generic database access to retrieve the various queries.
|
Package db provides generic database access to retrieve the various queries. |
|
Package dlog provides a door2doc logger that can be integrated with service logging.
|
Package dlog provides a door2doc logger that can be integrated with service logging. |
|
Package rest provides the client side implementation of the upload service REST API.
|
Package rest provides the client side implementation of the upload service REST API. |
|
Package web provides the web-based configuration interface for the service.
|
Package web provides the web-based configuration interface for the service. |
Click to show internal directories.
Click to hide internal directories.